@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 # Copyright 2014 Powerleader, PLCLOUD
 # Author: Joe Lei <jiaomin.lei@powerleader.com.cn>
-from keystoneclient.tests.plcloud import utils
-from keystoneclient.plcloud import ticket
+from plcloudclient.tests.v1_0 import utils
+from plcloudclient.v1_0 import ticket
 
 
 class TicketTests(utils.TestCase):
